@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -418,8 +418,12 @@ void SsiComponent::appendParsed(LinkedObj *p)
 
 
 SsiScript::SsiScript()
-//    : m_pConfig( NULL )
-    : m_pContent(NULL)
+    : m_iParserState(0)
+    , m_lModify(0)
+    , m_lSize(0)
+    , m_pCurComponent(NULL)
+    , m_pCurBlock(NULL)
+    , m_pContent(NULL)
 {
 }
 
